aboutsummaryrefslogtreecommitdiffstats
path: root/cps-path-parser/src/main/java
diff options
context:
space:
mode:
Diffstat (limited to 'cps-path-parser/src/main/java')
-rw-r--r--cps-path-parser/src/main/java/org/onap/cps/cpspath/parser/CpsPathBuilder.java52
-rw-r--r--cps-path-parser/src/main/java/org/onap/cps/cpspath/parser/CpsPathPrefixType.java (renamed from cps-path-parser/src/main/java/org/onap/cps/cpspath/parser/CpsPathQueryType.java)17
-rw-r--r--cps-path-parser/src/main/java/org/onap/cps/cpspath/parser/CpsPathQuery.java28
3 files changed, 50 insertions, 47 deletions
diff --git a/cps-path-parser/src/main/java/org/onap/cps/cpspath/parser/CpsPathBuilder.java b/cps-path-parser/src/main/java/org/onap/cps/cpspath/parser/CpsPathBuilder.java
index b9d0c25b1..ebf6fd3c9 100644
--- a/cps-path-parser/src/main/java/org/onap/cps/cpspath/parser/CpsPathBuilder.java
+++ b/cps-path-parser/src/main/java/org/onap/cps/cpspath/parser/CpsPathBuilder.java
@@ -20,18 +20,18 @@
package org.onap.cps.cpspath.parser;
+import static org.onap.cps.cpspath.parser.CpsPathPrefixType.DESCENDANT;
+
import java.util.HashMap;
import java.util.Map;
import org.onap.cps.cpspath.parser.antlr4.CpsPathBaseListener;
import org.onap.cps.cpspath.parser.antlr4.CpsPathParser.AncestorAxisContext;
-import org.onap.cps.cpspath.parser.antlr4.CpsPathParser.CpsPathWithDescendantAndLeafConditionsContext;
-import org.onap.cps.cpspath.parser.antlr4.CpsPathParser.CpsPathWithDescendantContext;
-import org.onap.cps.cpspath.parser.antlr4.CpsPathParser.CpsPathWithSingleLeafConditionContext;
+import org.onap.cps.cpspath.parser.antlr4.CpsPathParser.DescendantContext;
+import org.onap.cps.cpspath.parser.antlr4.CpsPathParser.IncorrectPrefixContext;
import org.onap.cps.cpspath.parser.antlr4.CpsPathParser.LeafConditionContext;
-import org.onap.cps.cpspath.parser.antlr4.CpsPathParser.MultipleValueConditionsContext;
-import org.onap.cps.cpspath.parser.antlr4.CpsPathParser.PostfixContext;
+import org.onap.cps.cpspath.parser.antlr4.CpsPathParser.MultipleLeafConditionsContext;
import org.onap.cps.cpspath.parser.antlr4.CpsPathParser.PrefixContext;
-import org.onap.cps.cpspath.parser.antlr4.CpsPathParser.SingleValueConditionContext;
+import org.onap.cps.cpspath.parser.antlr4.CpsPathParser.TextFunctionConditionContext;
public class CpsPathBuilder extends CpsPathBaseListener {
@@ -45,8 +45,8 @@ public class CpsPathBuilder extends CpsPathBaseListener {
}
@Override
- public void exitPostfix(final PostfixContext ctx) {
- throw new IllegalStateException(String.format("Unsupported postfix %s encountered in CpsPath.", ctx.getText()));
+ public void exitIncorrectPrefix(final IncorrectPrefixContext ctx) {
+ throw new IllegalStateException("CPS path can only start with one or two slashes (/)");
}
@Override
@@ -64,38 +64,18 @@ public class CpsPathBuilder extends CpsPathBaseListener {
}
@Override
- public void enterSingleValueCondition(final SingleValueConditionContext ctx) {
- leavesData.clear();
+ public void exitDescendant(final DescendantContext ctx) {
+ cpsPathQuery.setCpsPathPrefixType(DESCENDANT);
+ cpsPathQuery.setDescendantName(ctx.getText().substring(2));
}
@Override
- public void enterMultipleValueConditions(final MultipleValueConditionsContext ctx) {
+ public void enterMultipleLeafConditions(final MultipleLeafConditionsContext ctx) {
leavesData.clear();
}
@Override
- public void exitSingleValueCondition(final SingleValueConditionContext ctx) {
- final String leafName = ctx.leafCondition().leafName().getText();
- cpsPathQuery.setLeafName(leafName);
- cpsPathQuery.setLeafValue(leavesData.get(leafName));
- }
-
- @Override
- public void exitCpsPathWithSingleLeafCondition(final CpsPathWithSingleLeafConditionContext ctx) {
- cpsPathQuery.setCpsPathQueryType(CpsPathQueryType.XPATH_LEAF_VALUE);
- }
-
- @Override
- public void exitCpsPathWithDescendant(final CpsPathWithDescendantContext ctx) {
- cpsPathQuery.setCpsPathQueryType(CpsPathQueryType.XPATH_HAS_DESCENDANT_ANYWHERE);
- cpsPathQuery.setDescendantName(cpsPathQuery.getXpathPrefix().substring(1));
- }
-
- @Override
- public void exitCpsPathWithDescendantAndLeafConditions(
- final CpsPathWithDescendantAndLeafConditionsContext ctx) {
- cpsPathQuery.setCpsPathQueryType(CpsPathQueryType.XPATH_HAS_DESCENDANT_WITH_LEAF_VALUES);
- cpsPathQuery.setDescendantName(cpsPathQuery.getXpathPrefix().substring(1));
+ public void exitMultipleLeafConditions(final MultipleLeafConditionsContext ctx) {
cpsPathQuery.setLeavesData(leavesData);
}
@@ -104,6 +84,12 @@ public class CpsPathBuilder extends CpsPathBaseListener {
cpsPathQuery.setAncestorSchemaNodeIdentifier(ctx.ancestorPath().getText());
}
+ @Override
+ public void exitTextFunctionCondition(final TextFunctionConditionContext ctx) {
+ cpsPathQuery.setTextFunctionConditionLeafName(ctx.leafName().getText());
+ cpsPathQuery.setTextFunctionConditionValue(stripFirstAndLastCharacter(ctx.StringLiteral().getText()));
+ }
+
CpsPathQuery build() {
return cpsPathQuery;
}
diff --git a/cps-path-parser/src/main/java/org/onap/cps/cpspath/parser/CpsPathQuery.java b/cps-path-parser/src/main/java/org/onap/cps/cpspath/parser/CpsPathQuery.java
index 107bfa3e3..de7adf2b7 100644
--- a/cps-path-parser/src/main/java/org/onap/cps/cpspath/parser/CpsPathQuery.java
+++ b/cps-path-parser/src/main/java/org/onap/cps/cpspath/parser/CpsPathQuery.java
@@ -20,6 +20,8 @@
package org.onap.cps.cpspath.parser;
+import static org.onap.cps.cpspath.parser.CpsPathPrefixType.ABSOLUTE;
+
import java.util.Map;
import lombok.AccessLevel;
import lombok.Getter;
@@ -36,13 +38,13 @@ import org.onap.cps.cpspath.parser.antlr4.CpsPathParser;
@Setter(AccessLevel.PACKAGE)
public class CpsPathQuery {
- private CpsPathQueryType cpsPathQueryType;
private String xpathPrefix;
- private String leafName;
- private Object leafValue;
+ private CpsPathPrefixType cpsPathPrefixType = ABSOLUTE;
private String descendantName;
private Map<String, Object> leavesData;
private String ancestorSchemaNodeIdentifier = "";
+ private String textFunctionConditionLeafName;
+ private String textFunctionConditionValue;
/**
* Returns a cps path query.
@@ -68,7 +70,7 @@ public class CpsPathQuery {
}
/**
- * Has ancestor axis been populated.
+ * Has ancestor axis been included in cpsPath.
*
* @return boolean value.
*/
@@ -76,4 +78,22 @@ public class CpsPathQuery {
return !(ancestorSchemaNodeIdentifier.isEmpty());
}
+ /**
+ * Have leaf value conditions been included in cpsPath.
+ *
+ * @return boolean value.
+ */
+ public boolean hasLeafConditions() {
+ return leavesData != null;
+ }
+
+ /**
+ * Has text function condition been included in cpsPath.
+ *
+ * @return boolean value.
+ */
+ public boolean hasTextFunctionCondition() {
+ return textFunctionConditionLeafName != null;
+ }
+
}
diff --git a/cps-path-parser/src/main/java/org/onap/cps/cpspath/parser/CpsPathQueryType.java b/cps-path-parser/src/main/java/org/onap/cps/cpspath/parser/CpsPathPrefixType.java
index ac3e31334..dfac9b0c8 100644
--- a/cps-path-parser/src/main/java/org/onap/cps/cpspath/parser/CpsPathQueryType.java
+++ b/cps-path-parser/src/main/java/org/onap/cps/cpspath/parser/CpsPathPrefixType.java
@@ -22,19 +22,16 @@
package org.onap.cps.cpspath.parser;
/**
* The enum Cps path query type.
*/
-public enum CpsPathQueryType {
+public enum CpsPathPrefixType {
/**
- * Xpath descendant anywhere type e.g. //nodeName .
+ * Fully qualified Xpath starting from root with single slash e.g. /parent/child .
*/
- XPATH_HAS_DESCENDANT_ANYWHERE,
- /**
- * Xpath descendant anywhere type e.g. //nodeName[@leafName="value"] .
- */
- XPATH_HAS_DESCENDANT_WITH_LEAF_VALUES,
+ ABSOLUTE,
+
/**
- * Xpath leaf value cps path query type e.g. /cps-path[@leaf1="leafValue" and @leaf2=123] .
+ * Xpath descendant anywhere starting with double slash type e.g. //child/grandchild .
*/
- XPATH_LEAF_VALUE
+ DESCENDANT
}
@@ -22,19 +22,16 @@
package org.onap.cps.cpspath.parser;
/**
- * The enum Cps path query type.
+ * The enum Cps path prefix type.
*/